"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const js_1 = __importDefault(require("@bugsnag/js"));
const fastify_plugin_1 = __importDefault(require("fastify-plugin"));
function extractRequestMetadata(request) {
    var _a, _b;
    return {
        body: request.body,
        clientIp: (_b = (_a = request === null || request === void 0 ? void 0 : request.ips) === null || _a === void 0 ? void 0 : _a[0]) !== null && _b !== void 0 ? _b : request.ip,
        headers: request.raw.headers,
        httpMethod: request.routerMethod,
        params: request.params,
        path: request.routerPath,
        query: request.query,
        referer: request.raw.headers.referer,
        url: request.url
    };
}
function obtainRequestAndMetadataInfo(request) {
    const metadata = extractRequestMetadata(request);
    return {
        metadata,
        request: {
            clientIp: metadata.clientIp,
            headers: metadata.headers,
            httpMethod: metadata.httpMethod,
            referer: metadata.referer,
            url: metadata.url
        }
    };
}
function bugsnagPlugin(fastify, options, done) {
    js_1.default.start(options);
    fastify.decorate('bugsnag', js_1.default);
    fastify.decorateRequest('bugsnag', null);
    fastify.addHook('onRequest', function decorateRequestInstance(request, reply, next) {
        request.bugsnag = js_1.default;
        next();
    });
    fastify.addHook('onError', async function bugsnagErrorHandlerPlugin(request, reply, error) {
        this.bugsnag.notify(error, event => {
            const { metadata, request: requestData } = obtainRequestAndMetadataInfo(request);
            event.request = requestData;
            event.addMetadata('request', metadata);
        });
    });
    done();
}
exports.default = (0, fastify_plugin_1.default)(bugsnagPlugin, {
    fastify: '^4.x',
    name: 'fastify-bugsnag'
});
//# sourceMappingURL=index.js.map